@@ -1,4 +1,4 @@
-from aiida.orm import StructureData, KpointsData, Dict
+from aiida.orm import StructureData, KpointsData, Dict, Code
 from copy import deepcopy
 from aiida.orm import load_node
 from aiida.engine.launch import submit
@@ -278,8 +278,8 @@ def qePwContinueSubmit(results, pk, codename='', add_parameters={}, del_paramete
         else:
             restart_builder.metadata.description = node.description
     else:
-        restart_builder.metadata.label = node.label = node.label
-        restart_builder.metadata.description = node.description = node.description
+        restart_builder.metadata.label = node.label
+        restart_builder.metadata.description = node.description
 
     # submit the calculation
     restart_builder.structure = structure
@@ -291,7 +291,7 @@ def qePwContinueSubmit(results, pk, codename='', add_parameters={}, del_paramete
     # results
     results_tmp[str(calc.pk)] = {}
     results_tmp[str(calc.pk)]['uuid'] = calc.uuid
-    results_tmp[str(calc.pk)]['system'] = metadata['label']
+    results_tmp[str(calc.pk)]['system'] = node.label
     results_tmp[str(calc.pk)]['comp_type'] = parameters_default['CONTROL']['calculation']
     results_tmp[str(calc.pk)]['E/eV'] = None
     results_tmp[str(calc.pk)]['remove_remote_folder'] = False
